# Generated by Django 2.1.3 on 2018-11-16 12:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fsm_log', '0004_add_source_state'),
    ]

    operations = [
        migrations.AlterField(
            model_name='statelog',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
    ]
