# Generated by Django 2.1.3 on 2018-11-16 12:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fsm_log', '0005_description_null'),
    ]

    operations = [
        migrations.AlterField(
            model_name='statelog',
            name='object_id',
            field=models.TextField(db_index=True),
        ),
    ]
