# Generated by Django 2.1.4 on 2018-12-13 10:54

from django.db import migrations, models


class Migration(migrations.Migration):

    replaces = [('django_fsm_log', '0003_statelog_description'), ('django_fsm_log', '0004_add_source_state'), ('django_fsm_log', '0005_description_null')]

    dependencies = [
        ('django_fsm_log', '0002_auto_20151207_1521'),
    ]

    operations = [
        migrations.AddField(
            model_name='statelog',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='statelog',
            name='source_state',
            field=models.CharField(blank=True, db_index=True, default=None, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='statelog',
            name='state',
            field=models.CharField(db_index=True, max_length=255, verbose_name='Target state'),
        ),
    ]
