# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-07 15:21
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_fsm_log', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='statelog',
            options={'get_latest_by': 'timestamp'},
        ),
    ]
