# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-12-22 00:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_fsm_log', '0002_auto_20151207_1521'),
    ]

    operations = [
        migrations.AddField(
            model_name='statelog',
            name='description',
            field=models.TextField(blank=True),
        ),
    ]
